@@ -5,7 +5,7 @@
  - Licensed under the GNU AGPL version 3 or higher.
  -}
 
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE OverloadedStrings, CPP #-}
 
 module Command.EnableTor where
 
@@ -61,7 +61,7 @@ start _os = do
 			let ps = [Param (cmdname cmd), Param (show curruserid)]
 			sucommand <- liftIO $ mkSuCommand gitannex ps
 			cleanenv <- liftIO $ cleanStandaloneEnvironment
-			maybe noop showLongNote
+			maybe noop (showLongNote . UnquotedString)
 				(describePasswordPrompt' sucommand)
 			ifM (liftIO $ runSuCommand sucommand cleanenv)
 				( next checkHiddenService
@@ -111,7 +111,7 @@ checkHiddenService = bracket setup cleanup go
 		-- we just want to know if the tor circuit works.
 		liftIO (tryNonAsync $ connectPeer g addr) >>= \case
 			Left e -> do
-				warning $ "Unable to connect to hidden service. It may not yet have propigated to the Tor network. (" ++ show e ++ ") Will retry.."
+				warning $ UnquotedString $ "Unable to connect to hidden service. It may not yet have propigated to the Tor network. (" ++ show e ++ ") Will retry.."
 				liftIO $ threadDelaySeconds (Seconds 2)
 				check (n-1) addrs
 			Right conn -> do
